<?php

namespace App\Http\Controllers;

use App\Mahasiswa;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class ManajerController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function getManajer() {
        return Auth::user()->isManajer();
    }
    public function index()
    {
        //
        if($this->getManajer()) {
            return view('manajer.index');
        } else {
            return abort(403);
        }
    }

    public function controlMahasiswa() {
        $manajer = $this->getManajer();
        if($manajer) {
            $mahasiswa = Mahasiswa::join('users','users.id','=','mahasiswas.id')
                                    ->select('users.username','mahasiswas.*')
                                    ->where('status', '!=', Mahasiswa::STATUS_NOT_ACTIVE)
                                    ->where('status', '!=', Mahasiswa::STATUS_LULUS)
                                    ->orderBy('users.username','asc')
                                    ->get();

            return view('manajer.mahasiswa_control', ['mahasiswa' => $mahasiswa]);
        } else {
            abort(403);
        }
    }

    public function detailControlMahasiswa($username) {
        if($this->getManajer()) {
            $user = User::where('username', $username)->get()->first();
            $mahasiswa = $user->isMahasiswa();

            if ($mahasiswa) {
                // Error handling for invalid status change
                if(($mahasiswa->status == Mahasiswa::STATUS_TOPIK_DITERIMA || $mahasiswa->status == Mahasiswa::STATUS_TOPIK_DITOLAK) && $mahasiswa->t_topik2 == NULL ||
                    $mahasiswa->status == Mahasiswa::STATUS_SIAP_SEMINAR_TOPIK && $mahasiswa->t_topik3 == NULL ||
                    ($mahasiswa->status == Mahasiswa::STATUS_LULUS_SEMINAR_TOPIK || $mahasiswa->status == Mahasiswa::STATUS_GAGAL_SEMINAR_TOPIK) && $mahasiswa->t_topik4 == NULL ||
                    $mahasiswa->status == Mahasiswa::STATUS_MENUNGGU_PROPOSAL && $mahasiswa->t_proposal1 == NULL ||
                    $mahasiswa->status == Mahasiswa::STATUS_PROPOSAL_TELAH_DIAJUKAN && $mahasiswa->t_proposal2 == NULL ||
                    ($mahasiswa->status == Mahasiswa::STATUS_PROPOSAL_DITERIMA || $mahasiswa->status == Mahasiswa::STATUS_PROPOSAL_DITOLAK) && $mahasiswa->t_proposal3 == NULL ||
                    $mahasiswa->status == Mahasiswa::STATUS_SIAP_SEMINAR_PROPOSAL && $mahasiswa->t_proposal4 == NULL ||
                    ($mahasiswa->status == Mahasiswa::STATUS_LULUS_SEMINAR_PROPOSAL || $mahasiswa->status == Mahasiswa::STATUS_GAGAL_SEMINAR_PROPOSAL) && $mahasiswa->t_proposal4 == NULL ||
                    $mahasiswa->status == Mahasiswa::STATUS_DOSEN_PEMBIMBING_TELAH_DIPILIH && $mahasiswa->t_proposal4 == NULL ||
                    $mahasiswa->status == Mahasiswa::STATUS_MASA_BIMBINGAN && $mahasiswa->t_proposal4 == NULL || 
                    $mahasiswa->status == Mahasiswa::STATUS_SIAP_SEMINAR_TESIS && $mahasiswa->t_seminar1 == NULL ||
                    ($mahasiswa->status == Mahasiswa::STATUS_LULUS_SEMINAR_TESIS || $mahasiswa->status == Mahasiswa::STATUS_GAGAL_SEMINAR_TESIS) && $mahasiswa->t_seminar2 == NULL ||
                    $mahasiswa->status == Mahasiswa::STATUS_SIAP_SIDANG_TESIS && $mahasiswa->t_sidang == NULL
                ){
                    return abort(400);
                }

                return view('manajer.detail_mahasiswa_control',
                    [
                        'mahasiswa' => $mahasiswa,
                        'user' => $user,
                    ]
                );
            } else {
                return abort(404);
            }
        } else {
            return abort(403);
        }
    }
    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Mahasiswa  $mahasiswa
     * @return \Illuminate\Http\Response
     */
    public function show(Mahasiswa $mahasiswa)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Mahasiswa  $mahasiswa
     * @return \Illuminate\Http\Response
     */
    public function edit(Mahasiswa $mahasiswa)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Mahasiswa  $mahasiswa
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Mahasiswa $mahasiswa)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Mahasiswa  $mahasiswa
     * @return \Illuminate\Http\Response
     */
    public function destroy(Mahasiswa $mahasiswa)
    {
        //
    }
}
